import type { Commitment, PublicKey } from '@solana/web3.js';
import { Operation, OperationHandler } from '../../../types';
import { AuctionHouse, Listing } from '../models';
declare const Key: "FindListingByReceiptOperation";
/**
 * Finds a Listing by its receipt address.
 *
 * ```ts
 * const nft = await metaplex
 *   .auctionHouse()
 *   .findListingByReceipt({ receiptAddress, auctionHouse })
 *   .run();
 * ```
 *
 * @group Operations
 * @category Constructors
 */
export declare const findListingByReceiptOperation: import("../../../types").OperationConstructor<FindListingByReceiptOperation, "FindListingByReceiptOperation", FindListingByReceiptInput, Readonly<{
    model: "listing";
    lazy: false;
    auctionHouse: AuctionHouse;
    asset: import("../..").SftWithToken | import("../..").NftWithToken;
    tradeStateAddress: import("../../../types").Pda;
    sellerAddress: PublicKey;
    bookkeeperAddress: import("../../../utils").Option<PublicKey>;
    receiptAddress: import("../../../utils").Option<import("../../../types").Pda>;
    purchaseReceiptAddress: import("../../../utils").Option<PublicKey>;
    price: import("../../../types").SplTokenAmount | import("../../../types").SolAmount;
    tokens: import("../../../types").SplTokenAmount;
    createdAt: import("../../../types").DateTime;
    canceledAt: import("../../../utils").Option<import("../../../types").DateTime>;
}>>;
/**
 * @group Operations
 * @category Types
 */
export declare type FindListingByReceiptOperation = Operation<typeof Key, FindListingByReceiptInput, Listing>;
/**
 * @group Operations
 * @category Inputs
 */
export declare type FindListingByReceiptInput = {
    /**
     * The address of the listing receipt account.
     * This is the account that stores information about this listing.
     * The Listing model is built on top of this account.
     */
    receiptAddress: PublicKey;
    /** A model of the Auction House related to this listing. */
    auctionHouse: AuctionHouse;
    /**
     * Whether or not we should fetch the JSON Metadata for the NFT or SFT.
     *
     * @defaultValue `true`
     */
    loadJsonMetadata?: boolean;
    /** The level of commitment desired when querying the blockchain. */
    commitment?: Commitment;
};
/**
 * @group Operations
 * @category Handlers
 */
export declare const findListingByReceiptOperationHandler: OperationHandler<FindListingByReceiptOperation>;
export {};
