import type { Commitment } from '@solana/web3.js';
import { Operation, OperationHandler } from '../../../types';
import { LazyListing, Listing } from '../models/Listing';
declare const Key: "LoadListingOperation";
/**
 * Transforms a `LazyListing` model into a `Listing` model.
 *
 * ```ts
 * const listing = await metaplex
 *   .auctionHouse()
 *   .loadListing({ lazyListing })
 *   .run();
 * ```
 *
 * @group Operations
 * @category Constructors
 */
export declare const loadListingOperation: import("../../../types").OperationConstructor<LoadListingOperation, "LoadListingOperation", LoadListingInput, Readonly<{
    model: "listing";
    lazy: false;
    auctionHouse: import("..").AuctionHouse;
    asset: import("../../nftModule").SftWithToken | import("../../nftModule").NftWithToken;
    tradeStateAddress: import("../../../types").Pda;
    sellerAddress: import("@solana/web3.js").PublicKey;
    bookkeeperAddress: import("../../../utils").Option<import("@solana/web3.js").PublicKey>;
    receiptAddress: import("../../../utils").Option<import("../../../types").Pda>;
    purchaseReceiptAddress: import("../../../utils").Option<import("@solana/web3.js").PublicKey>;
    price: import("../../../types").SplTokenAmount | import("../../../types").SolAmount;
    tokens: import("../../../types").SplTokenAmount;
    createdAt: import("../../../types").DateTime;
    canceledAt: import("../../../utils").Option<import("../../../types").DateTime>;
}>>;
/**
 * @group Operations
 * @category Types
 */
export declare type LoadListingOperation = Operation<typeof Key, LoadListingInput, Listing>;
/**
 * @group Operations
 * @category Inputs
 */
export declare type LoadListingInput = {
    /** The `LazyListing` model to transform into the `Listing`.  */
    lazyListing: LazyListing;
    /**
     * Whether or not we should fetch the JSON Metadata for the NFT or SFT.
     *
     * @defaultValue `true`
     */
    loadJsonMetadata?: boolean;
    /** The level of commitment desired when querying the blockchain. */
    commitment?: Commitment;
};
/**
 * @group Operations
 * @category Handlers
 */
export declare const loadListingOperationHandler: OperationHandler<LoadListingOperation>;
export {};
